==> queen-beecon_1.0.3.tar.gz: queen-beecon-1.0.3/queen-beecon-progress-animation.h <==
/*
 * This file is a part of Queen Beecon Widget
 * queen-beecon-progress-animation: Utility for QBW progress animation management
 *
 * http://talk.maemo.org/showthread.php?t=45388
 *
 * Copyright (c) 2010 No!No!No!Yes! (Alessandro Peralma)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef QUEEN_BEECON_PROGRESS_ANIMATION_H
#define QUEEN_BEECON_PROGRESS_ANIMATION_H

typedef enum {
	QBW_INIT_PROGRESS_ANIMATION,
	QBW_CUSTOM_PROGRESS_ANIMATION,
	QBW_START_PROGRESS_ANIMATION,
	QBW_STOP_PROGRESS_ANIMATION,
	QBW_FRAME_PROGRESS_ANIMATION,
	QBW_DEINIT_PROGRESS_ANIMATION
} QbwProgressAnimationAction;

#define QBW_PROGRESS_ANIMATION_FRAMES_DEFAULT 4
#define QBW_PROGRESS_ANIMATION_FRAMES_TIMER_MSECS 200
#define QBW_PROGRESS_ANIMATION_FRAMES_TIMER_STEPS_MSECS 50

void queen_beecon_exec_animation_progress(QueenBeecon *self, QbwProgressAnimationAction action);

#endif /* QUEEN_BEECON_PROGRESS_ANIMATION_H */

==> queen-beecon_1.0.5.tar.gz: queen-beecon-1.0.5/queen-beecon-progress-animation.h <==
/*
 * This file is a part of Queen Beecon Widget
 * queen-beecon-progress-animation: Utility for QBW progress animation management
 *
 * http://talk.maemo.org/showthread.php?t=45388
 *
 * Copyright (c) 2010 No!No!No!Yes! (Alessandro Peralma)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef QUEEN_BEECON_PROGRESS_ANIMATION_H
#define QUEEN_BEECON_PROGRESS_ANIMATION_H

typedef enum {
	QBW_PROGRESS_ANIMATION_INIT,
	QBW_PROGRESS_ANIMATION_START,
	QBW_PROGRESS_ANIMATION_STOP,
	QBW_PROGRESS_ANIMATION_FRAME,
	QBW_PROGRESS_ANIMATION_DEINIT
} QbwProgressAnimationAction;

#define QBW_PROGRESS_ANIMATION_FRAMES_DEFAULT 4
#define QBW_PROGRESS_ANIMATION_FRAMES_TIMER_MSECS 200
#define QBW_PROGRESS_ANIMATION_FRAMES_TIMER_STEPS_MSECS 50

void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimationAction action);

#endif /* QUEEN_BEECON_PROGRESS_ANIMATION_H */
